// All of the Node.js APIs are available in the preload process.

const { contextBridge, ipcRenderer } = require('electron');

// It has the same sandbox as a Chrome extension.
window.addEventListener('DOMContentLoaded', () => {
	const replaceText = (selector, text) => {
		const element = document.getElementById(selector);
		if (element) element.innerText = text;
	};

	for (const type of ['chrome', 'node', 'electron']) {
		replaceText(`${type}-version`, process.versions[type]);
	}
});

contextBridge.exposeInMainWorld(
	'LBTray',
	{
		onShowPopup: (callback) => {
			ipcRenderer.on('showPopup', (event, message) => {
				callback();
			});
		},
		onLogout: (callback) => {
			ipcRenderer.on('logout', (event, message) => {
				callback();
			});
		},
		onConnect: (callback) => {
			ipcRenderer.on('connect', (event, message) => {
				callback();
			});
		},
		onConnectInternal: () => { // TODO: not a good name (should be changed in LBAdmin)
			ipcRenderer.send('connectInternal');
		},
		onDisconnect: (callback) => {
			ipcRenderer.on('disconnect', (event, message) => {
				callback();
			});
		},
		onDisconnectInternal: () => { // TODO: not a good name (should be changed in LBAdmin)
			ipcRenderer.send('disconnectInternal');
		},
		onHidePopup: (callback) => {
			ipcRenderer.on('hidePopup', (event, message) => {
				callback();
			});
		},
		onShortcutPress: (callback) => {
			ipcRenderer.on('shortcutPress', (event, message) => {
				callback();
			});
		},
		onClipboardChange: (callback) => {
			ipcRenderer.on('clipboardChange', (event, message) => {
				callback(message);
			});
		},
		onFocus: () => {
			ipcRenderer.on('focus', (event, message) => {
				document.documentElement.classList.remove('trayBlur');
				document.documentElement.className += ' trayFocus';
			});
		},
		onBlur: (callback) => {
			ipcRenderer.on('blur', (event, message) => {
				document.documentElement.classList.remove('trayFocus');
				document.documentElement.className += ' trayBlur';
				callback();
			});
		},
		isConnected: () => ipcRenderer.sendSync('isConnected'),
		isTransparent: () => ipcRenderer.sendSync('isTransparent'),
		changeIcon: (icon, title) => ipcRenderer.send('changeIcon', icon, title),
		registerShortcut: (shortcut) => ipcRenderer.send('registerShortcut', shortcut),
		isMainWindowVisible: () => ipcRenderer.sendSync('isMainWindowVisible'),
		hideMainWindow: () => ipcRenderer.send('hideMainWindow'),
		showMainWindow: () => ipcRenderer.send('showMainWindow'),
		openExternalBrowser: (url) => ipcRenderer.send('openExternalBrowser', url),
		openExternalApplication: (path) => ipcRenderer.send('openExternalApplication', path),
		openPopup: (name, url, width, height, frame) => ipcRenderer.send('openPopup', name, url, width, height, frame),
		closePopup: (name) => ipcRenderer.send('closePopup', name),
		emitMessage: (message) => ipcRenderer.send('emitMessage', message),
		listenMessage: (message, callback) => {
			ipcRenderer.on('msg-' + message, () => {
				callback();
			});
		},
		getServerURL: () => ipcRenderer.sendSync('getServerURL'),
		setServerURL: (url) => ipcRenderer.send('setServerURL', url),
		getPreviousServerURL: () => ipcRenderer.sendSync('getPreviousServerURL'),
		getVersion: () => ipcRenderer.sendSync('getVersion'),
		resizableMainWindow: (resizable) => ipcRenderer.send('resizableMainWindow', resizable),
		formatServerURL: () => ipcRenderer.sendSync('formatServerURL'),
		checkServer: (url) => ipcRenderer.invoke('checkServer', url),
		getPlatform: () => ipcRenderer.sendSync('getPlatform'),
		showNotification: (text, title, tag) => ipcRenderer.send('showNotification', text, title, tag),
		hideNotification: (tag) => ipcRenderer.send('hideNotification', tag),
	}
);
